
:orphan:

Dawson Labs
===========

Automatically generated index page for Dawson Labs:

.. raw:: html

   <ul>

   </ul>
     <a href="createcallregions.html">
       <p style="margin-bottom: 5px"><b>Create genomic call regions</b> <span style="margin-left: 10px; color: darkgray">CreateCallRegions</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="createcallregions.html" style="margin-bottom: 10px">
       v<b>0.1.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="freebayessomaticworkflow.html">
       <p style="margin-bottom: 5px"><b>Freebayes somatic workflow</b> <span style="margin-left: 10px; color: darkgray">FreeBayesSomaticWorkflow</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="freebayessomaticworkflow.html" style="margin-bottom: 10px">
       v<b>0.1.1</b>
     </a></p>
     </a>
     <hr />
         
     <a href="freebayessomaticworkflowcram.html">
       <p style="margin-bottom: 5px"><b>Freebayes somatic workflow (CRAM)</b> <span style="margin-left: 10px; color: darkgray">FreeBayesSomaticWorkflowCram</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="freebayessomaticworkflowcram.html" style="margin-bottom: 10px">
       v<b>0.1.1</b>
     </a></p>
     </a>
     <hr />
         
     <a href="mutect2jointsomaticworkflow.html">
       <p style="margin-bottom: 5px"><b>Mutect2 joint somatic variant calling workflow</b> <span style="margin-left: 10px; color: darkgray">Mutect2JointSomaticWorkflow</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="mutect2jointsomaticworkflow.html" style="margin-bottom: 10px">
       v<b>0.1.1</b>
     </a></p>
     </a>
     <hr />
         
     <a href="mutect2jointsomaticworkflowcram.html">
       <p style="margin-bottom: 5px"><b>Mutect2 joint somatic variant calling workflow (CRAM)</b> <span style="margin-left: 10px; color: darkgray">Mutect2JointSomaticWorkflowCram</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="mutect2jointsomaticworkflowcram.html" style="margin-bottom: 10px">
       v<b>0.1.1</b>
     </a></p>
     </a>
     <hr />
         
     <a href="strelka2passworkflow.html">
       <p style="margin-bottom: 5px"><b>Strelka 2Pass analysis</b> <span style="margin-left: 10px; color: darkgray">Strelka2PassWorkflow</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="strelka2passworkflow.html" style="margin-bottom: 10px">
       v<b>0.2</b>
     </a></p>
     </a>
     <hr />
         
     <a href="strelka2passworkflowcram.html">
       <p style="margin-bottom: 5px"><b>Strelka 2Pass analysis (CRAM)</b> <span style="margin-left: 10px; color: darkgray">Strelka2PassWorkflowCram</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="strelka2passworkflowcram.html" style="margin-bottom: 10px">
       v<b>0.2</b>
     </a></p>
     </a>
     <hr />
         
     <a href="callsomaticfreebayes.html">
       <p style="margin-bottom: 5px"><b>Call Somatic Variants from freebayes</b> <span style="margin-left: 10px; color: darkgray">callSomaticFreeBayes</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="callsomaticfreebayes.html" style="margin-bottom: 10px">
       v<b>0.1.8</b>
     </a></p>
     </a>
     <hr />
         
     <a href="refilterstrelka2calls.html">
       <p style="margin-bottom: 5px"><b>Refilter Strelka2 Variant Calls</b> <span style="margin-left: 10px; color: darkgray">refilterStrelka2Calls</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="refilterstrelka2calls.html" style="margin-bottom: 10px">
       v<b>0.1.8</b>
     </a></p>
     </a>
     <hr />
         

